@@ -41,6 +41,7 @@ import java.util.List;
 import java.util.stream.Collectors;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.function.Executable;
+import org.objectweb.asm.ConstantDynamic;
 import org.objectweb.asm.Handle;
 import org.objectweb.asm.Label;
 import org.objectweb.asm.Opcodes;
@@ -159,7 +160,7 @@ class GeneratorAdapterTest {
   void testPush_long() {
     assertEquals("LCONST_0", new Generator().push(0L));
     assertEquals("LCONST_1", new Generator().push(1L));
-    assertEquals("LDC 2", new Generator().push(2L));
+    assertEquals("LDC 2L", new Generator().push(2L));
   }
 
   @Test
@@ -167,14 +168,14 @@ class GeneratorAdapterTest {
     assertEquals("FCONST_0", new Generator().push(0.0f));
     assertEquals("FCONST_1", new Generator().push(1.0f));
     assertEquals("FCONST_2", new Generator().push(2.0f));
-    assertEquals("LDC 3.0", new Generator().push(3.0f));
+    assertEquals("LDC 3.0F", new Generator().push(3.0f));
   }
 
   @Test
   void testPush_double() {
     assertEquals("DCONST_0", new Generator().push(0.0));
     assertEquals("DCONST_1", new Generator().push(1.0));
-    assertEquals("LDC 2.0", new Generator().push(2.0));
+    assertEquals("LDC 2.0D", new Generator().push(2.0));
   }
 
   @Test
@@ -186,6 +187,8 @@ class GeneratorAdapterTest {
   @Test
   void testPush_type() {
     assertEquals("ACONST_NULL", new Generator().push((Type) null));
+    assertEquals(
+        "GETSTATIC java/lang/Void.TYPE : Ljava/lang/Class;", new Generator().push(Type.VOID_TYPE));
     assertEquals(
         "GETSTATIC java/lang/Boolean.TYPE : Ljava/lang/Class;",
         new Generator().push(Type.BOOLEAN_TYPE));
@@ -216,7 +219,7 @@ class GeneratorAdapterTest {
   void testPush_handle() {
     assertEquals("ACONST_NULL", new Generator().push((Handle) null));
     assertEquals(
-        "LDC pkg/Owner.nameI (2)",
+        "// handle kind 0x2 : GETSTATIC\n" + "    LDC pkg/Owner.name(I)",
         new Generator().push(new Handle(Opcodes.H_GETSTATIC, "pkg/Owner", "name", "I", false)));
   }
 
@@ -762,6 +765,28 @@ class GeneratorAdapterTest {
                 3));
   }
 
+  @Test
+  void testConstantDynamic() {
+    assertEquals(
+        "LDC name : Ljava/lang/Object; [\n"
+            + "      // handle kind 0x2 : GETSTATIC\n"
+            + "      pkg/Owner.name(I)\n"
+            + "      // arguments:\n"
+            + "      1, \n"
+            + "      2, \n"
+            + "      3\n"
+            + "    ]",
+        new Generator()
+            .push(
+                new ConstantDynamic(
+                    "name",
+                    "Ljava/lang/Object;",
+                    new Handle(Opcodes.H_GETSTATIC, "pkg/Owner", "name", "I", false),
+                    1,
+                    2,
+                    3)));
+  }
+
   @Test
   void testNewInstance() {
     assertEquals("NEW pkg/Class", new Generator().newInstance(Type.getObjectType("pkg/Class")));
@@ -902,6 +927,11 @@ class GeneratorAdapterTest {
       return toString();
     }
 
+    public String push(final ConstantDynamic constantDynamic) {
+      generatorAdapter.push(constantDynamic);
+      return toString();
+    }
+
     public String loadThis() {
       generatorAdapter.loadThis();
       return toString();
