@@ -29,6 +29,7 @@ package org.objectweb.asm;
 
 import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -61,6 +62,14 @@ class AnnotationVisitorTest extends AsmTest {
     assertEquals("Unsupported api 0", exception.getMessage());
   }
 
+  @Test
+  void testGetDelegate() {
+    AnnotationVisitor delegate = new AnnotationVisitor(Opcodes.ASM4) {};
+    AnnotationVisitor visitor = new AnnotationVisitor(Opcodes.ASM4, delegate) {};
+
+    assertSame(delegate, visitor.getDelegate());
+  }
+
   /**
    * Tests that ClassReader accepts visitor which return null AnnotationVisitor, and that returning
    * null AnnotationVisitor is equivalent to returning an EmptyAnnotationVisitor.
